@@ -93,6 +93,28 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
         Helper function implemented by child classes that create a new implicit API resource
         """
 
+    def _add_tags_to_implicit_api_if_necessary(
+        self, event_properties: Dict[str, Any], resource: SamResource, template: SamTemplate
+    ) -> None:
+        """
+        Decides whether to add tags to the implicit api resource.
+        :param dict template_dict: SAM template dictionary
+        """
+        # if the API ID provided in the event source properties, this implies that SAM-T will
+        # construct an implicit API resource for this API event source, and we need to add tags to the
+        # implicit API resource if customers specify `PropagateTags` property; otherwise, don't add tags
+        if self.API_ID_EVENT_PROPERTY in event_properties:
+            return
+
+        implicit_api_resource = template.get(self.IMPLICIT_API_LOGICAL_ID)
+        globals_var = template.get_globals().get(SamResourceType(resource.type).name, {})
+        should_propagate_tags = resource.properties.get("PropagateTags") or globals_var.get("PropagateTags")
+
+        if implicit_api_resource and resource.properties.get("Tags") and should_propagate_tags:
+            # This makes an assumption that the SAM resource has 'Tags' property and is a dictionary.
+            implicit_api_resource.properties.setdefault("Tags", {}).update(resource.properties["Tags"])
+            implicit_api_resource.properties["PropagateTags"] = True
+
     @cw_timer(prefix="Plugin-ImplicitApi")
     def on_before_transform_template(self, template_dict):  # type: ignore[no-untyped-def]
         """
@@ -371,7 +393,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
             raise ValueError("conditions_to_combine must have at least 2 conditions")
 
         template_conditions = template_dict.setdefault("Conditions", {})
-        new_template_conditions = make_combined_condition(sorted(list(conditions_to_combine)), condition_name)
+        new_template_conditions = make_combined_condition(sorted(conditions_to_combine), condition_name)
         # make_combined_condition() won't return None if `conditions_to_combine` has at least 2 elements,
         # which is checked above.
         # TODO: refactor the code to make the length check in one place only.
@@ -422,7 +444,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
         # slashes and curly braces for templated params, e.g., /foo/{customerId}. So we'll replace
         # non-alphanumeric characters.
         path_logical_id = path.replace("/", "SLASH").replace("{", "OB").replace("}", "CB")
-        return "{}{}PathCondition".format(api_id, path_logical_id)
+        return f"{api_id}{path_logical_id}PathCondition"
 
     def _maybe_remove_implicit_api(self, template):  # type: ignore[no-untyped-def]
         """
